@@ -9,7 +9,7 @@ import zipfile as z
 
 import numpy as np
 from mne.channels import make_standard_montage
-from mne.datasets.utils import _do_path_update, _get_path
+from mne.datasets.utils import _get_path
 from mne.io import read_raw_cnt
 from pooch import retrieve
 
@@ -116,7 +116,6 @@ class Zhou2016(BaseDataset):
             raise (ValueError("Invalid subject number"))
         key = "MNE_DATASETS_ZHOU2016_PATH"
         path = _get_path(path, key, "Zhou 2016")
-        _do_path_update(path, True, key, "Zhou 2016")
         basepath = os.path.join(path, "MNE-zhou-2016")
         if not os.path.isdir(basepath):
             os.makedirs(basepath)
