@@ -18,7 +18,7 @@ BBCI_URL = "http://doc.ml.tu-berlin.de/bbci/"
 
 
 def data_path(url, path=None, force_update=False, update_path=None, verbose=None):
-    return [dl.data_path(url, "BNCI", path, force_update, update_path, verbose)]
+    return [dl.data_dl(url, "BNCI", path, force_update, verbose)]
 
 
 @verbose
@@ -235,17 +235,16 @@ def _load_data_009_2014(
     filename = data_path(url, path, force_update, update_path)[0]
 
     data = loadmat(filename, struct_as_record=False, squeeze_me=True)["data"]
-    raws = []
+    sess = []
     event_id = {}
     for run in data:
         raw, ev = _convert_run_p300_sl(run, verbose=verbose)
-        raws.append(raw)
+        sess.append(raw)
         event_id.update(ev)
 
     sessions = {}
-    sessions["session_0"] = {}
-    for i, rawi in enumerate(raws):
-        sessions["session_0"]["run_" + str(i)] = rawi
+    for i, sessi in enumerate(sess):
+        sessions["session_" + str(i)] = {"run_0": sessi}
 
     return sessions
 
@@ -665,7 +664,6 @@ class MNEBNCI(BaseDataset):
     def data_path(
         self, subject, path=None, force_update=False, update_path=None, verbose=None
     ):
-        print(f"warning - datapath not implemented correctly for {self.code}")
         return load_data(
             subject=subject,
             dataset=self.code,
@@ -860,14 +858,14 @@ class BNCI2014004(MNEBNCI):
 
 
 class BNCI2014008(MNEBNCI):
-    """BNCI 2014-008 P300 dataset.
+    """BNCI 2014-008 P300 dataset
 
     Dataset from [1]_.
 
     **Dataset description**
 
     This dataset represents a complete record of P300 evoked potentials
-    using a paradigm originally described by Farwell and Donchin [2].
+    using a paradigm originally described by Farwell and Donchin [2]_.
     In these sessions, 8 users with amyotrophic lateral sclerosis (ALS)
     focused on one out of 36 different characters. The objective in this
     contest is to predict the correct character in each of the provided
@@ -898,7 +896,6 @@ class BNCI2014008(MNEBNCI):
 
     References
     ----------
-
     .. [1] A. Riccio, L. Simione, F. Schettini, A. Pizzimenti, M. Inghilleri,
            M. O. Belardinelli, D. Mattia, and F. Cincotti (2013). Attention
            and P300-based BCI performance in people with amyotrophic lateral
@@ -967,7 +964,7 @@ class BNCI2014009(MNEBNCI):
     def __init__(self):
         super().__init__(
             subjects=list(range(1, 11)),
-            sessions_per_subject=1,
+            sessions_per_subject=3,
             events={"Target": 2, "NonTarget": 1},
             code="009-2014",
             interval=[0, 0.8],
@@ -1032,10 +1029,10 @@ class BNCI2015003(MNEBNCI):
     **Dataset description**
 
     This dataset contains recordings from 10 subjects performing a visual P300
-    task for spelling. Results were published in [1]. Sampling frequency was
+    task for spelling. Results were published in [1]_. Sampling frequency was
     256 Hz and there were 8 electrodes ('Fz', 'Cz', 'P3', 'Pz', 'P4', 'PO7',
     'Oz', 'PO8') which were referenced to the right earlobe. Each subject
-    participated in only one session. For more information, see [1].
+    participated in only one session. For more information, see [1]_.
 
     References
     ----------
